@@ -4,7 +4,7 @@ import os
 import re
 import time
 from enum import Enum
-from typing import List, Literal, Set
+from typing import List, Literal, Set, Union
 
 import asyncpg
 
@@ -20,8 +20,14 @@ class SQLTaskInsertFileNotExists(Exception):
     pass
 
 
+_MULTILINE_COMMENT_REGEXP = re.compile(r"""\/\*[\s\S]*?\*\/""", flags=re.IGNORECASE)
+
+_COMMENT_REGEXP = re.compile(
+    r"""(?<!')--[^\r\n]*?$""", flags=re.IGNORECASE | re.MULTILINE
+)
+
 _FROM_JOIN_REGEXP = re.compile(
-    r"""(?:from|join)\s+"?(?P<after>[\w\d]*?"?\."?[\w\d]*)"?\s*""", flags=re.IGNORECASE
+    r"""(?:from|join)\s+(?P<after>"?[\w\d]*?"?\."?[\w\d]*"?)\s*""", flags=re.IGNORECASE
 )
 _INSERT_REGEXP = re.compile(
     r'(?P<before>insert\s*into\s*"?)([\w\d]*)(?P<after>"?\."?[\w\d]*"?)',
@@ -104,6 +110,10 @@ class SQLTask:
     cache_duration: int
     cache_filename: str
     no_cache: bool
+    start_timestamp: float
+    script_duration: Union[float, None] = None
+    test_start_timestamp: Union[float, None] = None
+    test_duration: Union[float, None] = None
 
     def __init__(
         self,
@@ -152,9 +162,20 @@ class SQLTask:
         with open(insert_file_path, "r") as f:
             return f.read()
 
+    def _clean_sql_script(self, query: str) -> str:
+        """removes comments from sql scripts"""
+        cleaned_query = _COMMENT_REGEXP.sub("", query)
+        cleaned_query = _MULTILINE_COMMENT_REGEXP.sub("", cleaned_query)
+        return cleaned_query
+
     def _parse_dependencies(self) -> Set[str]:
         return set(
-            [table.lower() for table in _FROM_JOIN_REGEXP.findall(self.get_insert())]
+            [
+                table.lower().replace('"', "")
+                for table in _FROM_JOIN_REGEXP.findall(
+                    self._clean_sql_script(self.get_insert())
+                )
+            ]
         )
 
     def remove_second_class_dependencies(
@@ -216,7 +237,7 @@ class SQLTask:
         repl = rf"\g<before>{self.dev_schema}\g<after>"
 
         def repl_fn(match: re.Match):
-            schema_table = match.groups()[0].lower()
+            schema_table = match.groups()[0].lower().replace('"', "")
             if schema_table in task_ids:
                 # Should do the replacement
                 _, table = schema_table.split(".")
@@ -227,8 +248,8 @@ class SQLTask:
 
         updated_query = re.sub(_CREATE_TABLE_REGEXP, repl, query)
         updated_query = re.sub(_DROP_TABLE_REGEXP, repl, updated_query)
-        updated_query = re.sub(_DELETE_REGEXP, repl, updated_query)
         updated_query = re.sub(_FROM_JOIN_REGEXP, repl_fn, updated_query)
+        updated_query = re.sub(_DELETE_REGEXP, repl, updated_query)
         updated_query = re.sub(_INSERT_REGEXP, repl, updated_query)
         updated_query = re.sub(_UPDATE_REGEXP, repl, updated_query)
         return updated_query
@@ -238,7 +259,7 @@ class SQLTask:
 
     def _set_cache(self, ddl_script: str, insert_script: str):
         with open(self.cache_filename, "w") as cache_file:
-            cache_file.write(f"{self._create_cache_key(ddl_script, insert_script)}")
+            cache_file.write(self._create_cache_key(ddl_script, insert_script))
             cache_file.write(",")
             cache_file.write(f"{time.time()}")
 
@@ -261,8 +282,15 @@ class SQLTask:
             return False
         return True
 
+    def _get_analyze(self):
+        schema, table = self.task_id.lower().split(".")
+        if self.stage == _constants._STAGE_DEV:
+            schema = self.dev_schema
+        return f"ANALYZE {schema}.{table};"
+
     async def execute(self, task_ids: Set[str]):
         self.status = SQLTaskStatus.RUNNING
+        self.start_timestamp = time.time()
         try:
             ddl_script = self.get_ddl()
             insert_script = self.get_insert()
@@ -280,8 +308,11 @@ class SQLTask:
             async with conn.transaction():
                 await conn.execute(ddl_script)
                 await conn.execute(insert_script)
+                await conn.execute(self._get_analyze())
             await conn.close()
+            self.script_duration = time.time() - self.start_timestamp
 
+            self.test_start_timestamp = time.time()
             test_futures = []
             granularity_columns_match = _GRANULARITY_TEST_REGEXP.search(insert_script)
             if granularity_columns_match is not None:
@@ -326,6 +357,7 @@ class SQLTask:
                 result, test_name = await test
                 if not result:
                     self.failed_tests.append(test_name)
+            self.test_duration = time.time() - self.test_start_timestamp
 
             if len(self.failed_tests) > 0:
                 w_print(
@@ -337,6 +369,8 @@ class SQLTask:
         except Exception as e:
             w_print(f"Task {self.task_id.lower()} failed:")
             print(e)
+            if self.script_duration is None:
+                self.script_duration = time.time() - self.start_timestamp
             self.status = SQLTaskStatus.FAILED
             return
         if self.stage == _constants._STAGE_DEV:
